---
title: <span class="badge object-type-scalar"></span> NanoFarad
---
# <span class="badge object-type-scalar"></span> NanoFarad

Energy: Nanofarad (nF)

## Definition

```python
# Energy: Nanofarad (nF)
NanoFarad: typing.Literal["nfarad"] = "nfarad"
```
